import { Construct } from '@aws-cdk/core';
/**
 * @stability stable
 */
export interface IVerifySesEmailAddressProps {
    /**
     * The email address to be verified, e.g. 'hello@example.org'.
     *
     * @stability stable
     */
    readonly emailAddress: string;
    /**
     * An optional AWS region to validate the email address.
     *
     * @default The custom resource will be created in the stack region
     * @stability stable
     */
    readonly region?: string;
}
/**
 * A construct to verify an SES email address identity.
 *
 * It initiates a verification so that SES sends a verification email to the desired email address. This means the owner of the email address still needs to act by clicking the link in the verification email.
 *
 * @stability stable
 * @example
 *
 * .org'
 * });
 */
export declare class VerifySesEmailAddress extends Construct {
    /**
     * @stability stable
     */
    constructor(parent: Construct, name: string, props: IVerifySesEmailAddressProps);
}
